@@ -139,12 +139,12 @@ int main(void)
 
 void byte_order(void)
 {
-    int i;
+    size_t i;
     v128_t e;
 
     printf("byte ordering of crypto/math datatypes:\n");
     for (i = 0; i < sizeof(e); i++)
-        e.v8[i] = i;
+        e.v8[i] = (uint8_t)i;
     printf("v128_t: %s\n", v128_hex_string(&e));
 }
 
@@ -155,12 +155,12 @@ void test_hex_string_funcs(void)
     char raw[10];
     int len;
 
-    len = hex_string_to_octet_string(raw, hex1, strlen(hex1));
+    len = hex_string_to_octet_string(raw, hex1, (int)strlen(hex1));
     printf("computed length: %d\tstring: %s\n", len,
            octet_string_hex_string(raw, len / 2));
     printf("expected length: %u\tstring: %s\n", (unsigned)strlen(hex1), hex1);
 
-    len = hex_string_to_octet_string(raw, hex2, strlen(hex2));
+    len = hex_string_to_octet_string(raw, hex2, (int)strlen(hex2));
     printf("computed length: %d\tstring: %s\n", len,
            octet_string_hex_string(raw, len / 2));
     printf("expected length: %d\tstring: %s\n", 16, "0123456789abcdef");
